<?php

namespace Restaurant\Website\Policies;

use Litepie\User\Contracts\UserPolicy;
use Restaurant\Website\Models\Website;

class WebsitePolicy
{

    /**
     * Determine if the given user can view the website.
     *
     * @param UserPolicy $user
     * @param Website $website
     *
     * @return bool
     */
    public function view(UserPolicy $user, Website $website)
    {
        if ($user->canDo('website.website.view') && $user->isAdmin()) {
            return true;
        }

        return $website->user_id == user_id() && $website->user_type == user_type();
    }

    /**
     * Determine if the given user can create a website.
     *
     * @param UserPolicy $user
     * @param Website $website
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('website.website.create');
    }

    /**
     * Determine if the given user can update the given website.
     *
     * @param UserPolicy $user
     * @param Website $website
     *
     * @return bool
     */
    public function update(UserPolicy $user, Website $website)
    {
        if ($user->canDo('website.website.edit') && $user->isAdmin()) {
            return true;
        }

        return $website->user_id == user_id() && $website->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given website.
     *
     * @param UserPolicy $user
     * @param Website $website
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Website $website)
    {
        return $website->user_id == user_id() && $website->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given website.
     *
     * @param UserPolicy $user
     * @param Website $website
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Website $website)
    {
        if ($user->canDo('website.website.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given website.
     *
     * @param UserPolicy $user
     * @param Website $website
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Website $website)
    {
        if ($user->canDo('website.website.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
